# Changelog

## 0.1.2 - 2019.01.06

- Fix CMake warning about automoc processing of generated files
- Add support for Python 3.7 (needed an update of PyYAML)
- Setup Travis and Tox
- Add installation instructions

## 0.1.1 - 2018.12.08

- Include all .md files in tarball
- Fix wrong description and license fields in package
- Add release check list

## 0.1.0 - 2018.12.08

- First release
